@@ -1,12 +1,6 @@
-# -*- coding: utf-8 -*-
-#
 # :copyright: (c) 2021 by Pavlo Dmytrenko.
 # :license: MIT, see LICENSE for more details.
-
-from __future__ import absolute_import
-
 from .api import kbi_safe_yaspin, yaspin
-from .base_spinner import Spinner
-
+from .core import Spinner
 
 __all__ = ("yaspin", "kbi_safe_yaspin", "Spinner")
